@@ -39,9 +39,9 @@ class Strategy(object):
         return self.__user_context
 
     def init(self):
-        logger.info("begin init")
+        logger.info("begin user strategy init")
         self.__init(self.__user_context)
-        logger.info("init complated")
+        logger.info("init user strategy complated")
 
     def handle_bar(self, event):
         self.__rebuild_event_data(event.data)
