@@ -28,6 +28,10 @@ class StrategyContext(object):
         if not hasattr(config,'risk'):
             return None
         return config.risk
+
+    def stop(self):
+        """停止策略"""
+        Environment.get_instance().event_bus.stop()
    
     def subscribe(self,*args):
         """行情订阅"""
