@@ -17,8 +17,9 @@ class EventBus(object):
         """引擎运行"""
         while self.__active == True:
             try:
-                event = self.__eventQueue.get()  
-                self.__event_process(event)
+                event = self.__eventQueue.get()
+                if self.__active == True:
+                    self.__event_process(event)
             except Exception as e:
                 logger.exception(e)
 
@@ -32,11 +33,12 @@ class EventBus(object):
         """启动"""
         self.__active = True
         self.__thread.start()
+        logger.info('启动策略事件')
 
     def stop(self):
         """停止"""
         self.__active = False
-        self.__thread.join()
+        logger.info('停止策略事件')
 
     def add_listener(self, event_type, handler):
         """绑定事件和监听器处理函数"""
