@@ -32,7 +32,7 @@ def on_init(ctx):
 
     id = ctx.get_strategy_id()
 
-    ctx.subscribe(('rb2010.SHFE','1m'),('jd2009.CFFEX','3m'))
+    ctx.subscribe(('cu2010.SHFE','1m'),('rr2009.DCE','1m'),('rb2010.SHFE','1m'),('sc2009.INE','1m'),('rb2010.SHFE','TICK'))
 
     ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
     conInfo = ctx.get_contract(ctx.domi_contract.symbol)
@@ -69,12 +69,12 @@ def on_init(ctx):
 
     ctx.insert_func_at_time(run_time,time(13,49,0))
 
-    ctx.insert_func_at_time(run_time,datetime(2020,5,21,14,10,0),'AAA','BBBB')
+    ctx.insert_func_at_time(run_time,datetime(2020,6,3,14,25,50),ctx)
 
     pass
 
 def run_time(*args):
-    pass
+    args[0][0].stop()
     
 def on_open(ctx):
     ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
@@ -146,29 +146,29 @@ def on_bar(ctx,bar):
     #    ctx.last_low = bar.low
 config = {
     "runtime":"DEBUG",
-    "run_type":"PAPER_TRADING",
+    "run_type":"LIVE_TRADING",
     "log":{
             'level':'INFO',
-            'file' :"/home/admin/logs/strategy.log",
+            'file' :"/home/sunliusi/logs/strategy.log",
         },
     #"ext_notify":{
     #        "type":"websocket",
     #        "address":"ws://localhost:14002/"
     #    },
-    "acct_info":{
-        "strategy_id":"21",
-        "account":"10030"
-    },
+    # "acct_info":{
+    #     "strategy_id":"21",
+    #     "account":"10030"
+    # },
     "risk":{
         "fixed_hand":10,
         "risk_ratio":1.0
-    }
-    #"acct_info":{
-    #        "strategy_id":"1021",
-    #        "account":"093959",
-    #        "password":"640423",
-    #        "comp_counter": 96,
-    #        "broker_type":152
-    #    }
+    },
+    "acct_info":{
+           "strategy_id":"1021",
+           "account":"093959",
+           "password":"640423",
+           "comp_counter":98,
+           "broker_type":152
+       }
 }
 run_func(**globals())
\ No newline at end of file
